diff libpurple/protocols/yahoo/yahoo_picture.h @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 4fc51a87ce42
line wrap: on
line diff
--- a/libpurple/protocols/yahoo/yahoo_picture.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/yahoo/yahoo_picture.h	Mon Mar 19 07:01:17 2007 +0000
@@ -1,7 +1,7 @@
 /*
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -24,21 +24,21 @@
 #ifndef _YAHOO_PICTURE_H_
 #define _YAHOO_PICTURE_H_
 
-void yahoo_send_picture_request(GaimConnection *gc, const char *who);
-void yahoo_send_picture_info(GaimConnection *gc, const char *who);
-void yahoo_send_picture_checksum(GaimConnection *gc);
-void yahoo_send_picture_update(GaimConnection *gc, int type);
-void yahoo_send_picture_update_to_user(GaimConnection *gc, const char *who, int type);
+void yahoo_send_picture_request(PurpleConnection *gc, const char *who);
+void yahoo_send_picture_info(PurpleConnection *gc, const char *who);
+void yahoo_send_picture_checksum(PurpleConnection *gc);
+void yahoo_send_picture_update(PurpleConnection *gc, int type);
+void yahoo_send_picture_update_to_user(PurpleConnection *gc, const char *who, int type);
 
-void yahoo_process_picture(GaimConnection *gc, struct yahoo_packet *pkt);
-void yahoo_process_picture_update(GaimConnection *gc, struct yahoo_packet *pkt);
-void yahoo_process_picture_checksum(GaimConnection *gc, struct yahoo_packet *pkt);
-void yahoo_process_picture_upload(GaimConnection *gc, struct yahoo_packet *pkt);
+void yahoo_process_picture(PurpleConnection *gc, struct yahoo_packet *pkt);
+void yahoo_process_picture_update(PurpleConnection *gc, struct yahoo_packet *pkt);
+void yahoo_process_picture_checksum(PurpleConnection *gc, struct yahoo_packet *pkt);
+void yahoo_process_picture_upload(PurpleConnection *gc, struct yahoo_packet *pkt);
 
-void yahoo_process_avatar_update(GaimConnection *gc, struct yahoo_packet *pkt);
+void yahoo_process_avatar_update(PurpleConnection *gc, struct yahoo_packet *pkt);
 
-void yahoo_set_buddy_icon(GaimConnection *gc, const char *iconfile);
-void yahoo_buddy_icon_upload(GaimConnection *gc, struct yahoo_buddy_icon_upload_data *d);
+void yahoo_set_buddy_icon(PurpleConnection *gc, const char *iconfile);
+void yahoo_buddy_icon_upload(PurpleConnection *gc, struct yahoo_buddy_icon_upload_data *d);
 void yahoo_buddy_icon_upload_data_free(struct yahoo_buddy_icon_upload_data *d);
 
 #endif /* _YAHOO_PICTURE_H_ */
@@ -1,7 +1,7 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.